PALM-meteo: palmmeteo.library.HorizonSelection Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo.library.HorizonSelection Class Reference

## Public Member Functions
| __init__ (self, cycles, earliest_horizon, idx_start=None, idx_stop=None, tindex=None, idx_rad=False)
| from_cfg (cls, cfgsect, idx_start=None, idx_stop=None, tindex=None, idx_rad=False)
| get_idx (self, horizon, dt_idx)
| locate (self, cycle, horizon=None, dt=None)
| dt_from_idx (self, idx)

## Public Attributes
| cycles
| horiz_first
| horiz_last
| idx0
| idx1
| tindex

## Detailed Description

    Represents a continous selection of forecast horizons for
    a given selection of cycles (AssimCycle)

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.library.HorizonSelection.__init__ | ( |  | self,
|  |  | cycles,
|  |  | earliest_horizon,
|  |  | idx_start = `None`,
|  |  | idx_stop = `None`,
|  |  | tindex = `None`,
|  |  | idx_rad = `False`
| ) |  |

## Member Function Documentation

## ◆ dt_from_idx()

palmmeteo.library.HorizonSelection.dt_from_idx | ( |  | self,
|  |  | idx
| ) |  |

## ◆ from_cfg()

palmmeteo.library.HorizonSelection.from_cfg | ( |  | cls,
|  |  | cfgsect,
|  |  | idx_start = `None`,
|  |  | idx_stop = `None`,
|  |  | tindex = `None`,
|  |  | idx_rad = `False`
| ) |  |

## ◆ get_idx()

palmmeteo.library.HorizonSelection.get_idx | ( |  | self,
|  |  | horizon,
|  |  | dt_idx
| ) |  |

## ◆ locate()

palmmeteo.library.HorizonSelection.locate | ( |  | self,
|  |  | cycle,
|  |  | horizon = `None`,
|  |  | dt = `None`
| ) |  |

## Member Data Documentation

## ◆ cycles

palmmeteo.library.HorizonSelection.cycles

## ◆ horiz_first

palmmeteo.library.HorizonSelection.horiz_first

## ◆ horiz_last

palmmeteo.library.HorizonSelection.horiz_last

## ◆ idx0

palmmeteo.library.HorizonSelection.idx0

## ◆ idx1

palmmeteo.library.HorizonSelection.idx1

## ◆ tindex

palmmeteo.library.HorizonSelection.tindex

The documentation for this class was generated from the following file:

- palmmeteo/library.py